@@ -60,15 +60,15 @@ supported architectures:
 
 available rop chain generators:
   execve (execve[=<cmd>], default /bin/sh) [Linux x86, x86_64]
-  mprotect  (mprotect=<address>:<size>) [Linux x86, x86_64]
-  virtualprotect (virtualprotect=<address iat vp>:<size>) [Windows x86]
+  mprotect  (mprotect address=0xdeadbeef size=0x10000) [Linux x86, x86_64]
+  virtualprotect (virtualprotect address=0xdeadbeef) [Windows x86]
 """,
 epilog="""example uses:
   [Generic]
   {0}
   {0} --file /bin/ls --console
 
-  [Informations]
+  [Information]
   {0} --file /bin/ls --info
   {0} --file /bin/ls --imports
   {0} --file /bin/ls --sections
@@ -79,7 +79,6 @@ epilog="""example uses:
   {0} --file /bin/ls --search "sub eax" --badbytes 000a0d
   {0} --file /bin/ls --search "sub eax" --detail
   {0} --file /bin/ls --filter "sub eax"
-  {0} --file /bin/ls --inst-count 5 --filter "sub eax"
   {0} --file /bin/ls --opcode ffe4
   {0} --file /bin/ls --opcode ffe?
   {0} --file /bin/ls --opcode ??e4
@@ -90,6 +89,7 @@ epilog="""example uses:
   {0} --file /bin/ls --chain execve
   {0} --file /bin/ls --chain "execve cmd=/bin/sh" --badbytes 000a0d
   {0} --file /bin/ls --chain "mprotect address=0xbfdff000 size=0x21000"
+  {0} --file /bin/ls /lib/libc.so.6 --console
 
 
   [Assemble/Disassemble]
@@ -126,7 +126,7 @@ epilog="""example uses:
         parser.add_argument(
             '--console', help='Starts interactive commandline', action='store_true')
         parser.add_argument(
-            '-f', '--file', metavar="<file>", help='The file to load')
+            '-f', '--file', metavar="<file>", help='The file to load', nargs='+')
         parser.add_argument(
             '-r', '--raw', help='Loads the file as raw file', action='store_true')
         parser.add_argument(
@@ -196,17 +196,15 @@ epilog="""example uses:
             '--nocolor', help='Disables colored output', action='store_true')
         parser.add_argument(
             '--clear-cache', help='Clears the cache', action='store_true')
+        parser.add_argument(
+            '--no-load', help='Don\'t load the gadgets automatically when start the console (--console)', action='store_true', default=False)
         return parser
 
     def _analyseArguments(self):
 
         if len(self.__argv) == 0:
             self.__argv.append('--console')
-        elif (len(self.__argv) == 1 and self.__argv[0] == '--nocolor' or self.__argv[0] == '--clear-cache'):
-            self.__argv.append('--console')
-        elif (len(self.__argv) == 2 and self.__argv[0] == '--nocolor' and self.__argv[1] == '--clear-cache'):
-            self.__argv.append('--console')
-        elif(len(self.__argv) == 2 and self.__argv[1] == '--nocolor' and self.__argv[0] == '--clear-cache'):
+        elif (len(self.__argv) == 1 and self.__argv[0] == '--nocolor'):
             self.__argv.append('--console')
             
         self.__args = self.__parser.parse_args(self.__argv)
@@ -247,7 +245,7 @@ epilog="""example uses:
             return vars(self.__args)[key]
 
     def isWindows(self):
-      return sys.platform.startswith('win')
+      return sys.platform.lower().startswith('win')
 
     def __setattr__(self, key, value):
         if key.startswith('_'):
